@@ -1,9 +1,8 @@
 import unittest
 import plotly.express as px
-import pandas as pd
 import cufflinks as cf
 from commodplot import commodplotutil as cpu
-from commodutil import transforms
+import os
 
 
 class TestCommodPlotUtil(unittest.TestCase):
@@ -34,13 +33,19 @@ class TestCommodPlotUtil(unittest.TestCase):
         self.assertTrue(isinstance(res['ch1'], str))
         self.assertTrue(isinstance(res['innerd']['ch2'], str))
 
-    def test_min_max_range(self):
-        df = cf.datagen.lines(1, 5000)
-        dft = transforms.seasonailse(df)
-        res = cpu.min_max_range(dft, shaded_range=5)
-        self.assertTrue(isinstance(res[0], pd.DataFrame))
-        self.assertTrue(isinstance(res[1], int))
+    def test_render_html(self):
+        dirname, filename = os.path.split(os.path.abspath(__file__))
+        test_out_loc = os.path.join(dirname, 'test.html')
+        if os.path.exists(test_out_loc):
+            os.remove(test_out_loc)
 
+        data = { 'name' : 'test' }
+        tfloc = os.path.join(os.path.join(os.path.join(dirname, os.pardir), 'templates'), 'base.html')
+        f = cpu.render_html(data, tfloc, 'test.html')
+
+        self.assertTrue(test_out_loc)
+        if os.path.exists(test_out_loc):
+            os.remove(test_out_loc)
 
 
 if __name__ == '__main__':
